# aiken_eng
A collection of tools for use at Aiken Engineering Company

## Plotting
A set of plot formatting dafaults to use with matplotlib.

Copyright 2026<br>
Aiken Engineering Company<br>
Eric Rudolph<br>
Houston, Texas